@@ -1,11 +1,9 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef LABELED_SLIDER_H
 #define LABELED_SLIDER_H
@@ -47,8 +45,8 @@ public:
     LabeledSlider(QWidget *parent, const QString &text,
                   int min, int max, int st);
 
-    LabeledSlider(QWidget *parent, KSaneOption *option);
-    ~LabeledSlider();
+    LabeledSlider(QWidget *parent, KSaneCore::Option *option);
+    ~LabeledSlider() override;
 
     int value() const;
 
@@ -60,8 +58,8 @@ public Q_SLOTS:
     void setStep(int);
     /** Set the unit */
     void setSuffix(const KLocalizedString &text);
-    
-    
+
+
 
 private Q_SLOTS:
 
